<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="100px">
      <el-form-item label="核算对象" prop="checkUnitId">
        <el-input
          v-model="queryParams.checkUnitName"
          placeholder="请输入核算对象"
          clearable
          @clear="handleQuery"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>

      <el-form-item label="核算时间">
        <el-date-picker
          v-model="daterangeCheckTime"
          style="width: 240px"
          value-format="yyyy-MM-dd HH:mm:ss"
          type="daterange"
          range-separator="-"
          start-placeholder="开始日期"
          end-placeholder="结束日期"
        ></el-date-picker>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
<!--      <el-col :span="1.5">-->
<!--        <el-button-->
<!--          type="primary"-->
<!--          plain-->
<!--          icon="el-icon-plus"-->
<!--          size="mini"-->
<!--          @click="handleAdd"-->
<!--          v-hasPermi="['system:checkResult:add']"-->
<!--        >新增</el-button>-->
<!--      </el-col>-->
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-card class="box-card" v-for="(item) in checkResultList">
      <div slot="header" class="clearfix">
        <span>{{ item.unitName }}</span>
        <el-button style="float: right; padding: 3px 0" type="text" @click="handleDetail(item)">核算</el-button>
      </div>
      <div class="text item">合同<span class="time">{{ item.contractName }}</span></div>
      <div class="text item">扣减金额<span class="time">{{ item.deductMoney }}</span></div>
      <div class="text item">最新核算时间
        <span class="time">{{ item.whichYear }}年{{ item.whichMonth }}月</span>
      </div>
      <el-button size="small" round style="float: right;margin-bottom: 18px;" @click="handlePublish(item)" v-show="item.publish != 1"  v-hasPermi="['result:contract:publish']">确认发布</el-button>
      <el-button size="small" round style="float: right;margin-bottom: 18px;" @click="handlePublish(item)" v-show="item.publish == 1"  v-hasPermi="['result:contract:publish']">已发布</el-button>
    </el-card>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <el-dialog :title="detailTitle" :visible.sync="detailOpen" width="760px" append-to-body>
      <div style="display: flex; flex-direction: row; width: 100%;margin-bottom: 10px; justify-content: center; align-items: center">
        <div style="line-height: 16px">应用规则：</div>
        <div v-for="ruleItem in detail.ruleList" style="display: flex; margin-right: 50px;">
          <div style="line-height: 16px;margin-right: 10px;display: flex; align-items: center">{{ ruleItem.scoreCondition }}分</div>
          <div style="line-height: 16px;max-width: 300px;word-wrap:break-word;word-break:normal;color: #2273b9">{{ ruleItem.description }}</div>
        </div>
      </div>

      <el-descriptions class="margin-top" :column="3" border>
<!--        <template slot="extra">-->
<!--          <el-button type="primary" size="small">操作</el-button>-->
<!--        </template>-->
        <el-descriptions-item>
          <template slot="label">
            <i class="el-icon-user"></i>
            核算对象
          </template>
          {{detail.unitName}}
        </el-descriptions-item>
        <el-descriptions-item>
          <template slot="label">
            <i class="el-icon-s-management"></i>
            合同名称
          </template>
          {{detail.contractName}}
        </el-descriptions-item>
      </el-descriptions>
        <el-table
          align="center"
          :data="detail.recordList"
          show-summary
          :summary-method="getSummaries"
          style="width: 100%;text-align:center">
          <el-table-column
            prop="createTime"
            label="核算日期"
            width="180">
          </el-table-column>
          <el-table-column
            prop="score"
            label="考核分数"
           >
            <template slot-scope="scope">
              <el-link @click="toScorePage(scope.row)">{{scope.row.score}}</el-link>
            </template>
          </el-table-column>
          <el-table-column
            label="扣减金额(元)"
            prop="money"
            width="180">
            <template slot-scope="scope">
              <el-input type="number"
                :precision="2" :step="0.1"
                :min="0" :max="1000000"
                v-model="scope.row.deductMoney"
                placeholder="请输入扣减金额">
              </el-input>
            </template>
          </el-table-column>
        </el-table>
        <div slot="footer" class="dialog-footer">
          <el-button type="primary" @click="submitForm">保 存</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>
    </el-dialog>

    <!-- 添加或修改考核结果对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { getCalculateReports, getCalculateReportById, backfill } from "@/api/platform/calculate-report";

export default {
  name: "CheckResult",
  data() {
    return {
      manualOpen: false,
      detailTitle: '',
      detailOpen: false,
      detail:{},
      manualScoreOpen: false,
      manualScoreForm: {},
      manualScoreTitle: '',
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 考核结果表格数据
      checkResultList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 逻辑删除时间范围
      daterangeCheckTime: [],
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        checkUnitId: null,
        checkTime: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    frequencyFormatter(row) {
      if (row.frequency === "1") {
        return "月度考核"
      }
      if (row.frequency === "2") {
        return "季度考核"
      }
    },
    examineRangeFormatter(row) {
      if (row.examineRange === "1") {
        return "分局考核"
      }
      if (row.examineRange === "2") {
        return "市局考核"
      }
    },
    /** 查询考核结果列表 */
    getList() {
      this.loading = true;
      if (null != this.daterangeCheckTime && '' != this.daterangeCheckTime) {
        this.queryParams["start"] = this.daterangeCheckTime[0];
        this.queryParams["end"] = this.daterangeCheckTime[1];
      }
      getCalculateReports(this.queryParams).then(response => {
        this.checkResultList = response.data;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.detailOpen = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        checkUnitId: null,
        checkPublishId: null,
        checkScore: null,
        systemScore: null,
        manualScore: null,
        checkTime: null,
        createTime: null,
        updateTime: null,
        deleted: null
      };
      this.resetForm("form");
    },
    cancelManualScore() {
      this.manualScoreForm = {};
      this.manualScoreTitle = "";
      this.manualScoreOpen = false;
    },
    submitManualScore() {
      if (! this.manualScoreForm.manualScore) {
        this.$modal.msgWarning("请填写分数");
        return
      }
      // manualScore(this.manualScoreForm).then(res => {
      //   this.$modal.msgSuccess("操作成功");
      //   this.cancelManualScore();
      //   this.getList();
      // })
    },
    handleDetail(row) {
      getCalculateReportById(row.id).then(res => {
        this.detail = res.data
        this.detailTitle = row.unitName + '考核结果'
        this.detailOpen = true
      })
    },
    handlePublish(row) {
      let text = row.publish == 1 ? '取消发布' : '发布';
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认' + text + '考核结果编号为"' + ids + '"的数据项？').then(function() {
        // return publishCheckResult(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess(text + "成功");
      }).catch(() => {});

    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.daterangeCheckTime = [];
      this.resetForm("queryForm");
      this.handleQuery();
    },
    /** 回填金额 */
    submitForm() {
      let data = {
        id: this.detail.id,
        recordList: this.detail.recordList
      }
      backfill(data).then(res => {
        if (res.code === 200) {
          this.$message.success("操作成功");
          this.detailOpen = false;
          this.getList();
        }
      })
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('system/checkResult/export', {
        ...this.queryParams
      }, `checkResult_${new Date().getTime()}.xlsx`)
    },
    /** 合计行 */
    getSummaries(param) {
      const { columns, data } = param;
      const sums = [];
      columns.forEach((column, index) => {
        if (index === 0) {
          sums[index] = '合计';
          return;
        }
        const values = data.map(item => Number(item[column.property]));
        if (!values.every(value => isNaN(value))) {
          sums[index] = values.reduce((prev, curr) => {
            const value = Number(curr);
            if (!isNaN(value)) {
              return prev + curr;
            } else {
              return prev;
            }
          }, 0);
          if (column.property === 'score') {
            sums[index] = '-';
          }
          if (column.property === 'value') {
            sums[index] += '元';
          }
        } else {
          sums[index] = '-';
        }
      });
      return sums;
    },
    toScorePage() {
    // 使用Vue Router进行页面跳转
    this.$router.push('/contract/score/index');
    },
  }
};
</script>
<style>
  .text {
    font-size: 14px;
  }
  .time {
    font-size: 13px;
    color: #999;
    margin-left: 10px;
  }
  .item {
    margin-bottom: 18px;
  }
  .clearfix:before,
  .clearfix:after {
    display: table;
    content: "";
  }
  .clearfix:after {
    clear: both
  }
  .box-card {
    width: calc(33% - 20px);
    min-width: 300px;
    margin: 15px 10px;
  }
</style>
